@@ -147,14 +147,14 @@ typedef struct BEAST2_RESULT {
 	F32PTR  time;
 	F32PTR  data;
 	F32PTR  marg_lik,sig2,R2,RMSE;
-	F32PTR  sncp;
+	F32PTR  sncp,sncp_median,sncp_mode,sncp_pct90;
 	I32PTR  sncpPr,scpOccPr;
 	F32PTR  sY,sSD;
 	F32PTR  sCI;            
 	I32PTR  sorder;         
 	F32PTR  samp,sampSD;   
 	F32PTR  scp,scpCI,scpPr,scpAbruptChange; 
-	F32PTR  tncp;
+	F32PTR  tncp,tncp_median,tncp_mode,tncp_pct90;
 	I32PTR  tncpPr,tcpOccPr;
 	F32PTR  tY,tSD;
 	F32PTR  tCI;            
@@ -162,11 +162,11 @@ typedef struct BEAST2_RESULT {
 	F32PTR  tslp,tslpSD;   
 	I32PTR  tslpSignPr;   
 	F32PTR  tcp,tcpCI,tcpPr,tcpAbruptChange; 
-	F32PTR  oncp;
+	F32PTR  oncp,oncp_median,oncp_mode,oncp_pct90;
 	I32PTR  oncpPr,ocpOccPr;
 	F32PTR  oY,oSD;
 	F32PTR  oCI;                 
-	F32PTR  ocp,ocpCI,ocpPr; 
+	F32PTR  ocp,ocpCI,ocpPr;  
 	F32PTR  spos_ncp,sneg_ncp;
 	I32PTR  spos_ncpPr,sneg_ncpPr;
 	I32PTR  spos_cpOccPr,sneg_cpOccPr;
