@@ -97,7 +97,7 @@ void  BEAST2_WriteOutput(A(OPTIONS_PTR) opt,A(RESULT_PTR) result,I64 pixelIndex)
 #define  _5(x,y,z,v,v1)   _4(x,y,z,v),_(v1)
 	if (hasSeasonCmpnt) {
 		len=1,offset=pixelIndex - 1,stride=0;
-		_(sncp);
+		_(sncp); _(sncp_median); _(sncp_mode); _(sncp_pct90);
 		len=(seasonMaxKnotNum+1);  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(sncpPr);
 		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
@@ -116,7 +116,7 @@ void  BEAST2_WriteOutput(A(OPTIONS_PTR) opt,A(RESULT_PTR) result,I64 pixelIndex)
 		}
 	}
 		len=1,offset=pixelIndex - 1,stride=0;
-		_(tncp);
+		_(tncp); _(tncp_median); _(tncp_mode); _(tncp_pct90);
 		len=(trendMaxKnotNum+1);  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(tncpPr);
 		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
@@ -135,7 +135,7 @@ void  BEAST2_WriteOutput(A(OPTIONS_PTR) opt,A(RESULT_PTR) result,I64 pixelIndex)
 		}
 	if (hasOutlierCmpnt) {
 		len=1,offset=pixelIndex - 1,stride=0;
-		_(oncp);
+		_(oncp); _(oncp_median); _(oncp_mode); _(oncp_pct90);
 		len=(outlierMaxKnotNum+1);  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(oncpPr);
 		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
@@ -145,7 +145,7 @@ void  BEAST2_WriteOutput(A(OPTIONS_PTR) opt,A(RESULT_PTR) result,I64 pixelIndex)
 			_(oCI);
 		}
 		if (opt->extra.computeOutlierChngpt) {
-			len=outlierMaxKnotNum;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
+			len=outlierMaxKnotNum;    GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 			_2(ocp,ocpPr);
 			len=outlierMaxKnotNum * 2; GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 			_(ocpCI);
@@ -237,70 +237,107 @@ void  MR_WriteOutput(A(OPTIONS_PTR) opt,A(RESULT_PTR) result,I64 pixelIndex)
 			WriteF32ArraryToStrideMEM(result->data+i*N,mat[i].data,len,stride,offset,datType);
 		}
 	}
-	#define  _(x) WriteF32ArraryToStrideMEM((F32PTR)result->x,mat->x,len,stride,offset,datType)
-	#define  _2(x,y) _(x),_(y)
-	#define  _3(x,y,z) _2(x,y),_(z)
-	#define  _4(x,y,z,v) _3(x,y,z),_(v)
+	#define  _(x)          WriteF32ArraryToStrideMEM((F32PTR)result->x,mat->x,len,stride,offset,datType)
+	#define  _2(x,y)        _(x),_(y)
+	#define  _3(x,y,z)      _2(x,y),_(z)
+	#define  _4(x,y,z,v)    _3(x,y,z),_(v)
 	#define  _5(x,y,z,v,v1) _4(x,y,z,v),_(v1)
 	if (hasSeasonCmpnt) {
 		len=1,offset=pixelIndex - 1,stride=0;
-		_(sncp);      
+		_(sncp); _(sncp_median); _(sncp_mode); _(sncp_pct90);
 		len=(seasonMaxKnotNum+1);  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(sncpPr);    
 		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(scpOccPr);   
+		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		for (I32 i=0; i < q;++i) {			
-			len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 			WriteF32ArraryToStrideMEM(result->sY+N*i,mat[i].sY,len,stride,offset,datType);
 			WriteF32ArraryToStrideMEM(result->sSD+N*i,mat[i].sSD,len,stride,offset,datType);
 		}
-		if (opt->extra.computeSeasonOrder) _(sorder);
-		if (opt->extra.computeSeasonAmp)   _2(samp,sampSD);
+		if (opt->extra.computeSeasonOrder) {
+			len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
+			_(sorder);
+		}
+		if (opt->extra.computeSeasonAmp) {
+			len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
+			for (I32 i=0; i < q;++i) {
+				WriteF32ArraryToStrideMEM(result->samp+N * i,mat[i].samp,len,stride,offset,datType);
+				WriteF32ArraryToStrideMEM(result->sampSD+N * i,mat[i].sampSD,len,stride,offset,datType);
+			}
+		}   
 		if (opt->extra.computeCredible) {
 			len=N * 2,GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
-			_(sCI);
+			for (I32 i=0; i < q;++i) {				
+				WriteF32ArraryToStrideMEM(result->sCI+N*i,mat[i].sCI,N,stride,offset,datType);				
+				WriteF32ArraryToStrideMEM(result->sCI+N*q+N*i,mat[i].sCI,N,stride,offset+N*stride,datType);
+			}			
 		}
 		if (opt->extra.computeSeasonChngpt) {
 			len=seasonMaxKnotNum;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
-			_3(scp,scpPr,scpAbruptChange);
+			_2(scp,scpPr);
+			for (int i=0; i < q;++i) {
+				WriteF32ArraryToStrideMEM(result->scpAbruptChange+len * i,mat[i].scpAbruptChange,len,stride,offset,datType);
+			}
 			len=seasonMaxKnotNum * 2; GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 			_(scpCI);
 		}
 	}
+	if (hasTrendCmpnt) {
 		len=1,offset=pixelIndex - 1,stride=0;
-		_(tncp);           
+		_(tncp); _(tncp_median); _(tncp_mode); _(tncp_pct90);
 		len=(trendMaxKnotNum+1);  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(tncpPr);         
 		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(tcpOccPr);       
-		for (I32 i=0; i < q;++i) {
-			len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
+		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
+		for (I32 i=0; i < q;++i) {			
 			WriteF32ArraryToStrideMEM(result->tY+N * i,mat[i].tY,len,stride,offset,datType);
 			WriteF32ArraryToStrideMEM(result->tSD+N * i,mat[i].tSD,len,stride,offset,datType);
-		}
-		return;
+		}		
 		if (opt->extra.computeTrendOrder)   _(torder);
-		if (opt->extra.computeTrendSlope)   _3(tslp,tslpSD,tslpSignPr);
+		if (opt->extra.computeTrendSlope) {
+			len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
+			for (I32 i=0; i < q;++i) {
+				WriteF32ArraryToStrideMEM(result->tslp+N * i,mat[i].tslp,len,stride,offset,datType);
+				WriteF32ArraryToStrideMEM(result->tslpSD+N * i,mat[i].tslpSD,len,stride,offset,datType);
+				WriteF32ArraryToStrideMEM(result->tslpSignPr+N * i,mat[i].tslpSignPr,len,stride,offset,datType);		
+			}			
+		}   		
 		if (opt->extra.computeCredible) {
 			len=N * 2,GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
-			_(tCI);
+			for (I32 i=0; i < q;++i) {
+				WriteF32ArraryToStrideMEM(result->tCI+N * i,mat[i].tCI,N,stride,offset,datType);
+				WriteF32ArraryToStrideMEM(result->tCI+N * q+N * i,mat[i].tCI,N,stride,offset+N * stride,datType);
+			}	
 		}
 		if (opt->extra.computeTrendChngpt) {
 			len=trendMaxKnotNum;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
-			_3(tcp,tcpPr,tcpAbruptChange);
+			_2(tcp,tcpPr);
+			for (int i=0; i < q;++i) {
+				WriteF32ArraryToStrideMEM(result->tcpAbruptChange+len * i,mat[i].tcpAbruptChange,len,stride,offset,datType);
+			}
 			len=trendMaxKnotNum * 2; GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 			_(tcpCI);
 		}
+	}
 	if (hasOutlierCmpnt) {
 		len=1,offset=pixelIndex - 1,stride=0;
-		_(oncp);
+		_(oncp); _(oncp_median); _(oncp_mode); _(oncp_pct90);
 		len=(outlierMaxKnotNum+1);  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
 		_(oncpPr);
 		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
-		_3(ocpOccPr,oY,oSD);
+		_(ocpOccPr);
+		len=N;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
+		for (I32 i=0; i < q;++i) {
+			WriteF32ArraryToStrideMEM(result->oY+N * i,mat[i].oY,len,stride,offset,datType);
+			WriteF32ArraryToStrideMEM(result->oSD+N * i,mat[i].oSD,len,stride,offset,datType);
+		}
 		if (opt->extra.computeCredible) {
 			len=N * 2,GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
-			_(oCI);
+			for (I32 i=0; i < q;++i) {
+				WriteF32ArraryToStrideMEM(result->oCI+N * i,mat[i].oCI,N,stride,offset,datType);
+				WriteF32ArraryToStrideMEM(result->oCI+N * q+N * i,mat[i].oCI,N,stride,offset+N * stride,datType);
+			}
 		}
 		if (opt->extra.computeOutlierChngpt) {
 			len=outlierMaxKnotNum;  GetOutputOffsetStride(io,pixelIndex,len,&stride,&offset);
